{% extends "registration/base.html" %}

{% load i18n %}

{% block title %}{% trans "Password reset" %}{% endblock %}

{% block content %}
<h1>{% trans "Password reset" %}</h1>
<p>{% trans "Forgotten your password? Enter your e-mail address below, and we'll e-mail instructions for setting a new one." %}</p>

<form action="" class="hform" method="post">
    {% csrf_token %}
    {{ form.email.errors }}
    <p><label for="id_email">{% trans 'E-mail address:' %}</label>{{ form.email }}</p>
    <p><input type="submit" value="{% trans 'Reset' %}" /></p>
</form>
{% endblock %}
